Golang library to get current working directory absolute path or its name.
Usage
Download: go get -u github.com/g4s8/gopwd
Example:
import "github.com/g4s8/gopwd"
import "fmt"
func main() {
pwd, err := gopwd.Name()
if err != nil {
panic(err)
}
fmt.Printf("Current directory is %s\n", pwd)
}
Contribution
Fork repository, clone it, make changes,
push to new branch and submit a pull request.